@@ -399,7 +399,7 @@ init_role_lookup_table (AtspiRole *role_table)
   role_table[ATK_ROLE_PASSWORD_TEXT] = ATSPI_ROLE_PASSWORD_TEXT;
   role_table[ATK_ROLE_POPUP_MENU] = ATSPI_ROLE_POPUP_MENU;
   role_table[ATK_ROLE_PROGRESS_BAR] = ATSPI_ROLE_PROGRESS_BAR;
-  role_table[ATK_ROLE_PUSH_BUTTON] = ATSPI_ROLE_PUSH_BUTTON;
+  role_table[ATK_ROLE_BUTTON] = ATSPI_ROLE_BUTTON;
   role_table[ATK_ROLE_RADIO_BUTTON] = ATSPI_ROLE_RADIO_BUTTON;
   role_table[ATK_ROLE_RADIO_MENU_ITEM] = ATSPI_ROLE_RADIO_MENU_ITEM;
   role_table[ATK_ROLE_ROOT_PANE] = ATSPI_ROLE_ROOT_PANE;
